module Debate.Arguments.Nutrition.HealthSeeker exposing (..)

import Debate.Types exposing (..)


argumentHealthSeeker : Argument
argumentHealthSeeker =
     { argumentTitle = "Ancestral Health Consistency Checker"
    , propositionTitle = "If someone (who favours consuming ancestral foods to the exclusion of novel foods because they value reducing disease risk) is not in favour of consuming a novel food (that reduces disease risk when replacing an ancestral food), then that person would be acting against their values."
    , propositionSummary = "Essentially, if our interlocutor identifies as \"F\", then all we need to do is demonstrate to them that \"N\" exists, and we're essentially home free. If they accept that \"N\" exists and they also identify as \"F\", then they should be in favour of substituting such a novel food for such an ancestral food. If they don't then they have a contradiction."
    , proofLink = "https://www.umsu.de/trees/#(~7x(Px)~1~7y(Qy)~5~6x~6y(~3Rxy~5Sx)),(~7x(Px)),(~7y(Qy))|=(~6x~6y(~3Rxy~5Sx))"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) favours consuming ancestral foods to the exclusion of (y) because they value reducing disease risk"
          }
        , { definiendum = "Q(y)"
          , definiens = "(y) reduces disease risk when replacing an ancestral food"
          }
        , { definiendum = "R(x,y)"
          , definiens = "(x) is in favour of consuming that (y)"
          }
        , { definiendum = "S(x)"
          , definiens = "(x) would be acting against their values"
          }
        , { definiendum = "x"
          , definiens = "someone"
          }
        , { definiendum = "y"
          , definiens = "novel food"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If there exists someone who favours consuming ancestral foods to the exclusion of novel foods because they value reducing disease risk, and there exists a novel food that reduces disease risk when replacing an ancestral food, then if that person is not in favour of consuming that novel food, then that person would be acting against their values."
                  , notation = "(∃x(Px)∧∃y(Qy)→∀x∀y(¬Rxy→Sx))"
                  }
                , { premise = "There exists someone who favours consuming ancestral foods to the exclusion of novel foods because they value reducing disease risk."
                  , notation = "(∃x(Px))"
                  }
                , { premise = "There exists a novel food that reduces disease risk when replacing an ancestral food."
                  , notation = "(∃y(Qy))"
                  }
                ]
          , conclusion = "Therefore, if that person is not in favour of consuming that novel food, then that person would be acting against their values."
          , conclusionNotation = "(∴∀x∀y(¬Rxy→Sx))"
          }
        ]
    }