module Debate.Arguments.Nutrition.Malondialdehyde exposing (..)

import Debate.Types exposing (..)


argumentMalondialdehyde : Argument
argumentMalondialdehyde =
    { argumentTitle = "Atherogenic Omega-3 Reductio"
    , propositionTitle = "Omega-3s are atherogenic."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qm),(Pm~5~6x(Rx))%7C=(Ro)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) increases the risk of atherosclerosis"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) facilitates the oxidative modification of LDL particles"
          }
        , { definiendum = "R(x)"
          , definiens = "all (x) are atherogenic"
          }
        , { definiendum = "m"
          , definiens = "malondialdehyde"
          }
        , { definiendum = "o"
          , definiens = "omega-3s"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Something increases the risk of atherosclerosis if and only if something facilitates the oxidative modification of LDL particles."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Malondialdehyde facilitates the oxidative modification of LDL particles."
                  , notation = "(Qm)"
                  }
                , { premise = "If malondialdehyde increases the risk of atherosclerosis, then all malondialdehyde-producing fatty acids are atherogenic."
                  , notation = "(Pm→∀x(Rx))"
                  }
                ]
          , conclusion = "Therefore, omega-3s are atherogenic."
          , conclusionNotation = "(∴Ro)"
          }
        ]
    }
